<?php

namespace App\Filament\Resources;

use App\Filament\Resources\DomaineResource\Pages;
use App\Filament\Resources\DomaineResource\RelationManagers;
use App\Models\Domaine;
use Filament\Forms;
use Filament\Forms\Components\FileUpload;
use Filament\Forms\Components\RichEditor;
use Filament\Forms\Components\Select;
use Filament\Forms\Components\TextInput;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class DomaineResource extends Resource
{
    protected static ?string $model = Domaine::class;

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                TextInput::make('author')
                ->required()
                ->string()
                ->maxLength(100),
                Select::make('type')
                    ->label('Type de Document')
                    ->required()
                    ->options([
                        'TFC' => 'TFC',
                        'Mémoire' => 'Mémoire',
                        'TFE' => 'TFE',
                        'Rapport de stage' => 'Rapport de stage',
                        'CV' => 'CV',
                        'Livres' => 'Livres',
                        'Thèse' => 'Thèse',
                        'Dissertation' => 'Dissertation',
                        'Travail Dirigé' => 'Travail Dirigé'
                    ])
                    ->searchable()
                    ->default('TFC'),
               TextInput::make('title')
                ->required()
                ->string()
                ->maxLength(255),
                FileUpload::make('picture')
                ->required(),
//                Forms\Components\TextInput::make('description')
//                ->required()
//                ->string()
                RichEditor::make('description')
                ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('author')
                ->searchable()
                ->sortable(),
                Tables\Columns\TextColumn::make('title')
                ->searchable()
                ->sortable(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListDomaines::route('/'),
            'create' => Pages\CreateDomaine::route('/create'),
            'edit' => Pages\EditDomaine::route('/{record}/edit'),
        ];
    }
}
